@@ -17,7 +17,7 @@ pub(crate) struct State<V: XXVault> {
     identity_public_key: Option<PublicKey>,
     ephemeral_secret: Option<Secret>,
     ephemeral_public: Option<PublicKey>,
-    remote_static_public_key: Option<PublicKey>,
+    _remote_static_public_key: Option<PublicKey>,
     remote_ephemeral_public_key: Option<PublicKey>,
     dh_state: DhState<V>,
     nonce: u16,
@@ -53,7 +53,7 @@ impl<V: XXVault> State<V> {
             identity_public_key: None,
             ephemeral_secret: None,
             ephemeral_public: None,
-            remote_static_public_key: None,
+            _remote_static_public_key: None,
             remote_ephemeral_public_key: None,
             dh_state: DhState::empty(vault.clone()),
             nonce: 0,
@@ -186,18 +186,7 @@ impl<V: XXVault> State<V> {
     fn finalize(self, encrypt_key: Secret, decrypt_key: Secret) -> Result<CompletedKeyExchange> {
         let h = self.h.ok_or(XXError::InvalidState)?;
 
-        let local_static_secret = self.identity_key.ok_or(XXError::InvalidState)?;
-
-        let remote_static_public_key =
-            self.remote_static_public_key.ok_or(XXError::InvalidState)?;
-
-        Ok(CompletedKeyExchange::new(
-            h,
-            encrypt_key,
-            decrypt_key,
-            local_static_secret,
-            remote_static_public_key,
-        ))
+        Ok(CompletedKeyExchange::new(h, encrypt_key, decrypt_key))
     }
 }
 
@@ -255,7 +244,7 @@ impl<V: XXVault> State<V> {
         self.h = Some(h);
         let rs = PublicKey::new(rs);
         self.dh_state.dh(&ephemeral_secret_handle, &rs)?;
-        self.remote_static_public_key = Some(rs);
+        self._remote_static_public_key = Some(rs);
         self.nonce = 0;
 
         let (payload, h) = self.decrypt_and_mix_hash(encrypted_payload_and_tag)?;
@@ -366,7 +355,7 @@ impl<V: XXVault> State<V> {
             self.decrypt_and_mix_hash(&message_3[public_key_size + AES_GCM_TAGSIZE..])?;
         self.h = Some(h);
         self.nonce += 1;
-        self.remote_static_public_key = Some(rs);
+        self._remote_static_public_key = Some(rs);
         Ok(payload)
     }
 
@@ -540,35 +529,31 @@ mod tests {
         let mut initiator = Initiator::new(initiator);
         let mut responder = Responder::new(responder);
 
-        let res = responder.process(&[]);
-        assert!(res.is_err());
-        let res = initiator.process(&decode(MSG_1_PAYLOAD).unwrap());
+        let res = initiator.generate_request(&decode(MSG_1_PAYLOAD).unwrap());
         assert!(res.is_ok());
         let msg1 = res.unwrap();
         assert_eq!(encode(&msg1), MSG_1_CIPHERTEXT);
 
-        let res = responder.process(&msg1);
+        let res = responder.handle_response(&msg1);
         assert!(res.is_ok());
-        let res = responder.process(&decode(MSG_2_PAYLOAD).unwrap());
+        let res = responder.generate_request(&decode(MSG_2_PAYLOAD).unwrap());
         assert!(res.is_ok());
         let msg2 = res.unwrap();
         assert_eq!(encode(&msg2), MSG_2_CIPHERTEXT);
 
-        let res = initiator.process(&msg2);
+        let res = initiator.handle_response(&msg2);
         assert!(res.is_ok());
-        let res = initiator.process(&decode(MSG_3_PAYLOAD).unwrap());
+        let res = initiator.generate_request(&decode(MSG_3_PAYLOAD).unwrap());
         assert!(res.is_ok());
         let msg3 = res.unwrap();
         assert_eq!(encode(&msg3), MSG_3_CIPHERTEXT);
 
-        let res = responder.process(&msg3);
+        let res = responder.handle_response(&msg3);
         assert!(res.is_ok());
 
-        let initiator = Box::new(initiator);
         let res = initiator.finalize();
         assert!(res.is_ok());
         let alice = res.unwrap();
-        let responder = Box::new(responder);
         let res = responder.finalize();
         assert!(res.is_ok());
         let bob = res.unwrap();
@@ -634,7 +619,7 @@ mod tests {
             identity_public_key: Some(static_public_key),
             ephemeral_secret: Some(ephemeral_secret_handle),
             ephemeral_public: Some(ephemeral_public_key),
-            remote_static_public_key: None,
+            _remote_static_public_key: None,
             remote_ephemeral_public_key: None,
             dh_state: DhState {
                 key: None,
